==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/WebPaneDragEndEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPaneDragEndEventArgsDetailDescriptionMetadata } from "./WebPaneDragEndEventArgsDetailDescriptionMetadata";
import { WebPaneDragEndEventArgsDescription } from "./WebPaneDragEndEventArgsDescription";
/**
 * @hidden
 */
export let WebPaneDragEndEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPaneDragEndEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebPaneDragEndEventArgsDescriptionMetadata.a == null) {
                WebPaneDragEndEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPaneDragEndEventArgsDescriptionMetadata.c(WebPaneDragEndEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebPaneDragEndEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebPaneDragEndEventArgsDescriptionMetadata.a);
            WebPaneDragEndEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:PaneDragEndEventArgs");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebPaneDragEndEventArgsDetail");
        }
        static d(a) {
            WebPaneDragEndEventArgsDescriptionMetadata.b(a);
            a.ad("WebPaneDragEndEventArgs", () => new WebPaneDragEndEventArgsDescription());
            a.ac("WebPaneDragEndEventArgs", WebPaneDragEndEventArgsDescriptionMetadata.a);
        }
    }
    WebPaneDragEndEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebPaneDragEndEventArgsDescriptionMetadata, 'WebPaneDragEndEventArgsDescriptionMetadata');
    WebPaneDragEndEventArgsDescriptionMetadata.a = null;
    return WebPaneDragEndEventArgsDescriptionMetadata;
})();

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm2015/lib/WebPaneDragEndEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPaneDragEndEventArgsDetailDescriptionMetadata } from "./WebPaneDragEndEventArgsDetailDescriptionMetadata";
import { WebPaneDragEndEventArgsDescription } from "./WebPaneDragEndEventArgsDescription";
/**
 * @hidden
 */
export let WebPaneDragEndEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPaneDragEndEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebPaneDragEndEventArgsDescriptionMetadata.a == null) {
                WebPaneDragEndEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPaneDragEndEventArgsDescriptionMetadata.c(WebPaneDragEndEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebPaneDragEndEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebPaneDragEndEventArgsDescriptionMetadata.a);
            WebPaneDragEndEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:PaneDragEndEventArgs");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebPaneDragEndEventArgsDetail");
        }
        static d(a) {
            WebPaneDragEndEventArgsDescriptionMetadata.b(a);
            a.ae("WebPaneDragEndEventArgs", () => new WebPaneDragEndEventArgsDescription());
            a.ad("WebPaneDragEndEventArgs", WebPaneDragEndEventArgsDescriptionMetadata.a);
        }
    }
    WebPaneDragEndEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebPaneDragEndEventArgsDescriptionMetadata, 'WebPaneDragEndEventArgsDescriptionMetadata');
    WebPaneDragEndEventArgsDescriptionMetadata.a = null;
    return WebPaneDragEndEventArgsDescriptionMetadata;
})();
